import {
  scaleTime,
  extent,
  histogram as bin,
  timeMonths,
  timeFormat,
  sum,
  scaleLinear,
  max,
} from 'd3';
import { AxisBottom } from './AxisBottom';
import { AxisLeft } from './AxisLeft';

const width = 960;
const margin = {
  top: 0,
  bottom: 35,
  left: 60,
  right: 30,
};

const tickOffset = 5;
const xAxisLabelOffset = 28;
const yAxisLabelOffset = -105;

const xAxisLabel = 'Month';
const yAxisLabel = 'Total Dead and Missing';

const xValue = (d) => d.time;
const yValue = (d) => d.total;

const xAxisTickFormat = timeFormat('%m/%d/%y');

import { line, curve, curveCardinal } from 'd3';

export const Marks = ({
  yScale,
  xScale,
  binnedData,
  tooltipFormat,
  innerHeight,
}) => (
  <g className="marks">
    {binnedData.map((d) => (
      <rect
        className="mark"
        x={xScale(d.x0)}
        y={yScale(d.y)}
        width={xScale(d.x1) - xScale(d.x0)}
        height={innerHeight - yScale(d.y)}
        fill={'darkred'}
      >
        <title>{`${tooltipFormat(d.x0)}\nTotal: ${
          d.y
        }`}</title>
      </rect>
    ))}
  </g>
);

export const DateHistogram = ({ migrants, height }) => {
  const innerHeight = height - margin.top - margin.bottom;
  const innerWidth = width - margin.left - margin.right;

  const xScale = scaleTime()
    .domain(extent(migrants, xValue))
    .range([0, innerWidth])
    .nice();

  const binnedData = bin()
    .value(xValue)
    .domain(xScale.domain())
    .thresholds(
      timeMonths(xScale.domain()[0], xScale.domain()[1])
    )(migrants)
    .map((array) => ({
      y: sum(array, yValue),
      x0: array.x0,
      x1: array.x1,
    }));

  const yScale = scaleLinear()
    .domain([0, max(binnedData, (d) => d.y)])
    .range([innerHeight, 0])

  return (
    <>
      <rect fill={'darkgrey'} width={width} height={height} opacity={'1'} />
    <g
      transform={`translate(${margin.left}, ${margin.top})`}
    >
      <rect fill={'white'} width={innerWidth} height={innerHeight} opacity={'1'} />
      <AxisBottom
        xScale={xScale}
        innerHeight={innerHeight}
        tickFormat={xAxisTickFormat}
        tickOffset={tickOffset}
      />
      <AxisLeft
        yScale={yScale}
        innerWidth={innerWidth}
        tickOffset={tickOffset}
      />
      <text
        x={innerWidth / 2}
        style={{ textAnchor: 'middle' }}
        y={innerHeight + xAxisLabelOffset}
        className="axis-label"
      >
        {xAxisLabel}
      </text>
      <text
        x={innerHeight + yAxisLabelOffset}
        style={{ textAnchor: 'middle' }}
        y={-innerHeight / 2 - 8}
        className="y-axis-label"
        transform="rotate(-90)"
      >
        {yAxisLabel}
      </text>
      <Marks
        xScale={xScale}
        yScale={yScale}
        binnedData={binnedData}
        tooltipFormat={xAxisTickFormat}
        innerHeight={innerHeight}
      />
    </g>
      </>
  );
};
