import React from 'react';
import ReactDOM from 'react-dom';
import { useWorldAtlas } from './useWorldAtlas';
import { useMigrants } from './useMigrants';
import { BubbleMap } from './BubbleMap/index.js';
import { DateHistogram } from './DateHistogram/index.js';

const width = 960;
const height = 500;
const dateHistogramSize = 0.2;

const App = () => {
  const worldAtlas = useWorldAtlas();
  const migrants = useMigrants();

  if (!worldAtlas || !migrants) {
    return <pre>Loading...</pre>;
  }

  return (
    <svg width={width} height={height}>
      <BubbleMap migrants={migrants} worldAtlas={worldAtlas} />
      <g transform={`translate(0, ${height - dateHistogramSize * height})`}>
        <DateHistogram
          migrants={migrants}
          width={width}
          height={dateHistogramSize * height}
        />
      </g>
    </svg>
  );
};
const rootElement = document.getElementById('root');
ReactDOM.render(<App />, rootElement);
